import numpy as np
import matplotlib.pyplot as plt

global muVacio
global muFeRel
global kDisp
global cteRoz
global g

densidadHierro = 7800 # kg/m3
muVacio = 4*np.pi*1e-7
muFeRel = 5000
kDisp = 2 # cte de dispersion
cteRoz = 0.1
g = 9.8

__author__ = 'Oscar Suescun' 

def calcular_diametro_ext(longitudBobina, diametroCuBobina, espirasBobina, diametroInteriorBobina):
    
    espirasCapa = int(longitudBobina/diametroCuBobina)
    numeroCapas = int(espirasBobina/espirasCapa +.5)

    return 2 * numeroCapas * diametroCuBobina + diametroInteriorBobina

def reluctancia_funcX(longFe, diamFe, longC, diamCint, diamCu, espiras):
    '''
    Esta funcion devuelve un vector que contenga la reluctancia total en
    funcion de la distancia que recorre el vastago dentro de la bobina.

    Para esto se utiliza un vector de 0 -> longC con un estep de longC/100

    Entrada:
        - longFe --> longitud del vastago
        - diamFe --> diametro del vastago
        - longC --> longitud de la bobina
        - diamCint --> diametro interior de la bobina
        - diamCu --> diametro del hilo de cobre
        - espiras --> numero de espiras en la bobina

    Salida:
        - relTotal --> devuelve un vector con la reluctancia total en 
                       funcion de la distancia recorrida en la bobina.

    '''

    diamCext = calcular_diametro_ext(longC, diamCu, espiras, diamCint)

    seccionFe = (np.pi * diamFe**2) / 4
    seccionSc = (np.pi * diamCext**2) / 4
    seccionDisp = (np.pi * (kDisp * diamCint)**2) / 4

    x = np.arange(0,longC + longC/100, longC/100)
    longFe = np.full(len(x), longFe)
    longC = np.full(len(x), longC)


    relFe = longFe / (muVacio * muFeRel * seccionFe)
    relDisp = longC / (muVacio * seccionDisp)
    relAire = (longC - x) / (muVacio * seccionSc)
    relFlujo = (longC + longFe - x) / (muVacio * seccionDisp)

    relTotal = relFe + relDisp + relAire + relFlujo

    return relTotal


def induccion(corriente, reluctancia, espiras, diamFe):
    flujo = espiras * corriente / reluctancia

    secFe = np.pi * diamFe**2 / 4

    return flujo / secFe

def fuerza_magnetica(corriente, reluctancia, espiras, diamFe):

    b = induccion(corriente, reluctancia, espiras, diamFe)

    secFe = np.pi * diamFe**2 / 4

    return 0.5 * b**2 * secFe / muVacio

def aceleracion(masa, anguloDisparo, fuerzaMagnetica):

    anguloDisparo = anguloDisparo * np.pi / 180

    return fuerzaMagnetica/masa - g*(cteRoz * np.cos(anguloDisparo) + np.sen(anguloDisparo))
    
    



if __name__ == '__main__':

    numeroModulos = 1

    longitudBobina = 53.21e-3 # m
    diametroInteriorBobina = 6.035-3 * 2 # m
    espirasBobina = 500
    diametroCuBobina = 0.8e-3 # m

    longitudVastago = 96e-3 # m
    diametroVastago = 3.045e-3 * 2 # m


